@@ -18,6 +18,7 @@ languages = {
     "pl": "Polish",
     "pt-br": "Brazilian Portuguese",
     "ro": "Romanian",
+    "ru": "Russian",
     "sr": "Serbian",
     "sv": "Swedish",
     "uk": "Ukrainian",
@@ -34,6 +35,7 @@ no_dev_packages = {
     "mk",
     "nb",
     "ro",
+    "ru",
     "sv",
     "sr",
     "vi",
